/*
 * Copyright 2011 Cedric Duval <cedricduval@free.fr>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2.
 *
 * See the accompanying COPYING file for more details.
 */

/**
 * \file
 * Shell commands generation
 */

#ifndef _KUULTO_CMDGEN_H
#define _KUULTO_CMDGEN_H

struct cmdgen_context;

/**
 * Initialize commands generation
 *
 * \param[in] in   Input stream: test file
 * \param[in] out  Output stream
 *
 * \return         A handle suitable for use with cmdgen_process_input()
 *                 or NULL in case of error
 */
struct cmdgen_context *cmdgen_init(FILE *in, FILE *out);

/**
 * Process a line of test input
 *
 * Memory and I/O streams implicitly released when processing is over.
 *
 * \param[in] c  Handle obtained with cmdgen_init()
 *
 * \return       The number of line processed (0 indicates end of input)
 *               or -1 in case of error
 */
int cmdgen_process_line(struct cmdgen_context *c);

/**
 * Process a whole test input stream
 *
 * Memory and I/O streams implicitly released when processing is over.
 *
 * \param[in] in   Input stream: test file
 * \param[in] out  Output stream
 *
 * \return         0 if processing went ok, -1 otherwise
 *
 * this wraps cmdgen_init() and cmdgen_process_input() into a single
 * function for convenience
 */
int cmdgen_process_stream(FILE *in, FILE *out);

#endif /* _KUULTO_CMDGEN_H */
