/*
 * Copyright 2011 Cedric Duval <cedricduval@free.fr>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2.
 *
 * See the accompanying COPYING file for more details.
 */

/**
 * \file
 * Handling of temporary test directories
 *
 * Upon start, a temporary directory is created, and all tests are executed
 * in a different directory thereof. Upon exit this temporary directory is
 * removed, unless otherwise specified via tmpdir_keep().
 */

#ifndef _KUULTO_TMPDIR_H
#define _KUULTO_TMPDIR_H

/**
 * Create a new test temporary subdirectory
 *
 * \param[in] name  Name of the test; should not contain any slashes
 *
 * \return          0 in case of success, -1 otherwise
 */
int tmpdir_create(const char *name);

/**
 * Specify that the test directories should be kept upon exit
 */
void tmpdir_keep();

#endif /* _KUULTO_TMPDIR_H */
