 ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
   Automatic escaping of command prefixes
 ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~


A test generating an output which may be interpreted as a command:

  $ cat <<EOF > test1.t
  >   $ echo '$ echo foo'
  >   $ echo "bar"
  > EOF


First exhibiting the wrong behavior. To that end, we use verbatim mode to
update the test. No escaping takes place, and a new command magically appears:

  $ kuulto-gen test1.t \
  >   | sh -           \
  >   | kuulto-merge -V test1.t > test1_V_up1.t
  $ cat test1_V_up1.t
    $ echo '$ echo foo'
    $ echo foo
    $ echo "bar"
    bar


Now a subsequent update, which should otherwise leave the test stable,
will instead produce unintended output:

  $ kuulto-gen test1_V_up1.t \
  >   | sh -                 \
  >   | kuulto-merge -V test1_V_up1.t > test1_V_up2.t
  $ cat test1_V_up2.t
    $ echo '$ echo foo'
    $ echo foo
    $ echo foo
    foo
    $ echo "bar"
    bar


Now let us follow the same procedure, but in normal (non-verbatim) mode,
which should produce proper escaping preventing that to happen:

  $ kuulto-gen test1.t \
  >   | sh -           \
  >   | kuulto-merge test1.t > test1_N_up1.t
  $ cat test1_N_up1.t
    $ echo '$ echo foo'
    \$ echo foo (esc)
    $ echo "bar"
    bar


And we verify that the test indeed remains stable and correct after
a second update:

  $ kuulto-gen test1_N_up1.t \
  >   | sh -                 \
  >   | kuulto-merge test1_N_up1.t > test1_N_up2.t
  $ cat test1_N_up2.t
    $ echo '$ echo foo'
    \$ echo foo (esc)
    $ echo "bar"
    bar


 ~~~~~~~~~~~~~~~~~~

A similar case, command-continuation lines:

  $ cat <<EOF > test2.t
  >   $ echo '> echo foo'
  >   $ echo 'bar'
  > EOF


First we verify that a double update would be problematic without escaping:

  $ kuulto-gen test2.t \
  >   | sh -           \
  >   | kuulto-merge -V test2.t > test2_V_up1.t
  $ kuulto-gen test2_V_up1.t \
  >   | sh -                 \
  >   | kuulto-merge -V test2_V_up1.t > test2_V_up2.t
  $ cmp -s test2_V_up1.t test2_V_up2.t && echo "Stable" || echo "Unstable"
  Unstable
  $ cat test2_V_up2.t
    $ echo '> echo foo'
    > echo foo
    > echo foo
    foo
    $ echo 'bar'
    bar


Then we confirm that in normal mode, escaping prevents that faulty behavior:

  $ kuulto-gen test2.t \
  >   | sh -           \
  >   | kuulto-merge test2.t > test2_N_up1.t
  $ kuulto-gen test2_N_up1.t \
  >   | sh -                 \
  >   | kuulto-merge test2_N_up1.t > test2_N_up2.t
  $ cmp -s test2_N_up1.t test2_N_up2.t && echo "Stable" || echo "Unstable"
  Stable
  $ cat test2_N_up2.t
    $ echo '> echo foo'
    \> echo foo (esc)
    $ echo 'bar'
    bar


 ~~~~~~~~~~~~~~~~~~

Same procedure, this time with two consecutive continuation lines:

  $ cat <<EOF > test3.t
  >   $ echo '> echo foo'; echo '> echo bar'
  >   $ echo 'baz'
  > EOF
  $ kuulto-gen test3.t \
  >   | sh -           \
  >   | kuulto-merge test3.t > test3_N_up1.t
  $ kuulto-gen test3_N_up1.t \
  >   | sh -                 \
  >   | kuulto-merge test3_N_up1.t > test3_N_up2.t
  $ cmp -s test3_N_up1.t test3_N_up2.t && echo "Stable" || echo "Unstable"
  Stable
  $ cat test3_N_up2.t
    $ echo '> echo foo'; echo '> echo bar'
    \> echo foo (esc)
    \> echo bar (esc)
    $ echo 'baz'
    baz


The end.
