 ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
   Regular expressions matching
 ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~


Unanchored matches:

  $ cat <<EOF > unanchored.t
  >   $ for yummy in "delectable" "and" "delicious"; do echo \$yummy; done
  >   tab (re)
  >   and (re)
  >   del (re)
  > EOF
  $ kuulto-run1 unanchored.t
   ________________________________________________________________________
  /                                                            unanchored.t
    $ for yummy in "delectable" "and" "delicious"; do echo $yummy; done
    tab (re)
    and (re)
    del (re)
  \________________________________________________________________________


Match all:

  $ cat <<EOF > matchall.t
  >   $ echo 'caught!'
  >   . (re)
  > EOF
  $ kuulto-run1 matchall.t
   ________________________________________________________________________
  /                                                              matchall.t
    $ echo 'caught!'
    . (re)
  \________________________________________________________________________


Anchors:

  $ cat <<EOF > anchors.t
  >   $ for w in "and" "bait" "fisherman" "knot" "hook"; do echo \$w; done
  >   ^and$ (re)
  >   it$ (re)
  >   ^.*is (re)
  >   not$ (re)
  >   ok$ (re)
  > EOF
  $ kuulto-run1 anchors.t
   ________________________________________________________________________
  /                                                               anchors.t
    $ for w in "and" "bait" "fisherman" "knot" "hook"; do echo $w; done
    ^and$ (re)
    it$ (re)
    ^.*is (re)
    not$ (re)
    ok$ (re)
  \________________________________________________________________________


Back-references:

  $ cat <<EOF > fruity.t
  > Fruity test:
  >
  >   $ echo banana
  >   ba(..)\1 (re)
  >
  >   $ echo ananas
  >   a(na)\1s (re)
  >
  > Yumm... on the other hand these should not work:
  >
  >   $ echo banana
  >   ba(...)\1 (re)
  >
  >   $ echo ananas
  >   a(ba)\1s
  > EOF
  $ kuulto-run1 fruity.t
   ________________________________________________________________________
  /                                                                fruity.t
  Fruity test:
  
    $ echo banana
    ba(..)\1 (re)
  
    $ echo ananas
    a(na)\1s (re)
  
  Yumm... on the other hand these should not work:
  
    $ echo banana
    banana
  
    $ echo ananas
    ananas
  \________________________________________________________________________


Brackets:

  $ cat <<EOF > brackets.t
  > Test brackets:
  >
  >   $ for word in "bet" "but" "bat" "bit"; do echo \$word; done
  >   b[a-z]t (re)
  >   b[o-u]t (re)
  >   b[ai]t (re)
  >   b[io]t (re)
  >
  > And now some that are meant to fail:
  >
  >   $ echo "dry"
  >   [tpf]ry (re)
  >
  >   $ echo "cry"
  >   [tpf]ry (re)
  > EOF
  $ kuulto-run1 brackets.t
   ________________________________________________________________________
  /                                                              brackets.t
  Test brackets:
  
    $ for word in "bet" "but" "bat" "bit"; do echo $word; done
    b[a-z]t (re)
    b[o-u]t (re)
    b[ai]t (re)
    b[io]t (re)
  
  And now some that are meant to fail:
  
    $ echo "dry"
    dry
  
    $ echo "cry"
    cry
  \________________________________________________________________________


One or more:

  $ cat <<EOF > plus.t
  >   $ echo "I am nonplussed by this test"
  >   I am nonplus+ed by this test (re)
  >
  >   $ echo "100 x 100 = 10000"
  >   100 x 100 = 100+ (re)
  > EOF
  $ kuulto-run1 plus.t
   ________________________________________________________________________
  /                                                                  plus.t
    $ echo "I am nonplussed by this test"
    I am nonplus+ed by this test (re)
  
    $ echo "100 x 100 = 10000"
    100 x 100 = 100+ (re)
  \________________________________________________________________________


Mix of normal matches and regexp matches:

  $ cat <<EOF > mix.t
  >   $ for pet in cat snake dog elephant spider; do echo \$pet; done
  >   ^...$ (re)
  >   snake
  >   d[iou]g (re)
  >   elephant
  >   ide (re)
  > EOF
  $ kuulto-run1 mix.t
   ________________________________________________________________________
  /                                                                   mix.t
    $ for pet in cat snake dog elephant spider; do echo $pet; done
    ^...$ (re)
    snake
    d[iou]g (re)
    elephant
    ide (re)
  \________________________________________________________________________


Ranges:

  $ cat <<EOF > ranges.t
  >   $ echo hotshots
  >   (hots){2,} (re)
  >
  >   $ echo singing; echo murmurs
  >   ^s(ing)+$ (re)
  >   ^(mur){2,2}s$ (re)
  > EOF
  $ kuulto-run1 ranges.t
   ________________________________________________________________________
  /                                                                ranges.t
    $ echo hotshots
    (hots){2,} (re)
  
    $ echo singing; echo murmurs
    ^s(ing)+$ (re)
    ^(mur){2,2}s$ (re)
  \________________________________________________________________________


Lines with a regexp marker but meant to be matched literally:

  $ cat <<EOF > literal.t
  >   $ echo "w[oo]dcu[tt]er (re)"
  >   w[oo]dcu[tt]er (re)
  >
  >   $ echo "marooned+ (re)"
  >   marooned+ (re)
  > EOF
  $ kuulto-run1 literal.t
   ________________________________________________________________________
  /                                                               literal.t
    $ echo "w[oo]dcu[tt]er (re)"
    w[oo]dcu[tt]er (re)
  
    $ echo "marooned+ (re)"
    marooned+ (re)
  \________________________________________________________________________


The end.
