 ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
   Buffer used for commands generation
 ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~


Commands are appended into a buffer as they are parsed, and printed out as
soon as a complete group (a command and its continuation lines if any) is
found to be over. The buffer is comfortable enough for many command lines,
and is thus only reset it when it nears BUFSIZ, to prevent it from growing
too large over time.

Creating a test file with long command lines:

  $ {
  >   echo "  $ echo start"
  >   for i in $(seq 1 300); do
  >     echo "  > : # line of command, just a filler getting nothing done"
  >   done
  >   echo "  > echo last"
  >   echo "  start"
  >   echo "  last"
  >   echo "  $ echo end"
  >   echo "  end"
  >   echo " ... and it is finally over"
  > } > big.t  # generating commands

A typical BUFSIZ is 8192; this goes all the way over 16 kB:

  $ wc -c < big.t
  18091

A glimpse of the resulting test file (filler lines compressed as one):

  $ uniq < big.t
    $ echo start
    > : # line of command, just a filler getting nothing done
    > echo last
    start
    last
    $ echo end
    end
   ... and it is finally over

This test file should trigger at least a buffer growth and a reset of the
buffer. Checking that command generation goes on smoothly after those events:

  $ KUULTO_SALT=SALT kuulto-gen < big.t > big.out

  $ sed -n '/^echo [^"]/p' big.out
  echo start
  echo last
  echo end

  $ uniq < big.out
  echo "|klp| SALT 2"
  echo "SALT $? 302 2 *= @"
  echo start
  : # line of command, just a filler getting nothing done
  echo last
  echo "SALT $? 1 1 =# @"
  echo end
  echo "SALT $? 1 0 #. @"
  echo "SALT $? 0 0 .. @"


The end.
