#!/bin/sh
#
# Process a test file, and display the result of all intermediate steps.
# For development/debugging purposes.

set -e
set -u

usage()
{
    cat <<EOF | sed 's,^...,,'

    Usage: $1 [ <options> ] <test>

    Options:
    -h,--help          show this help text
    -V,--verbatim      disable escaping and regexp/glob support

EOF
    exit 0
}

abspath() { [ "$(echo "$1" | cut -b1)" = "/" ] && echo $1 || echo $(pwd)/$1; }
topdir="$(abspath $(dirname $0)/..)"
. ${topdir}/utils/env
PATH="${topdir}/build/tools:${PATH}"

t=""
while [ -n "${1:-}" ]; do
    case $1 in
        -h|--help) usage $0 ;;
        -V|--verbatim) MERGE_ARGS="-V" ;;
        -*) echo "Invalid option: \"$1\""; exit 1 ;;
        *)
            if [ -z "$t" ]; then
                t="$(echo $1 | sed 's,\.[^.]*$,,').t"
                tname="$(basename $t)"
            else
                echo "Only one test allowed"
                exit 1;
            fi
            ;;
    esac
    shift
done


header()
{
    d="________________________________________"
    printf "%s%s%s_\n" "${d}" "${d}" "${1:-}" | sed 's,^.*\(.\{79\,\}\)$,\1,'
}

tdir="$(mktemp -d)"
cp ${t} ${tdir}/
cd ${tdir}

header "test_file"
cat ${tname}

header "generating_commands"
cmdgen < ${tname} > ${tname}.sh

header "commands"
cat ${tname}.sh

header "output"
sh - < ${tname}.sh > ${tname}.out 2>&1
cat ${tname}.out

header "merging"
merge ${MERGE_ARGS:-} ${tname} < ${tname}.out > ${tname}.merged

header "merged_output"
cat ${tname}.merged

header "diff"
diff -u ${tname} ${tname}.merged || :

header

rm -rf ${tdir}
